@@ -28,9 +28,9 @@ namespace GmmLib
     class NON_PAGED_SECTION PlatformInfoGen9 : public PlatformInfo
     {
     public:
-        PlatformInfoGen9(PLATFORM &Platform);
+        PlatformInfoGen9(PLATFORM &Platform, Context *pGmmLibContext);
         ~PlatformInfoGen9(){};
     };
 }
 
-#endif
\ No newline at end of file
+#endif
